bayespy.inference.vmp.transformations.RotateGaussianARD.__init__
================================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotateGaussianARD.__init__